@@ -2,10 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import sale
-from . import purchase
-from . import stock
-from . import product
+
+from . import product, purchase, sale, stock
 
 
 def register():
@@ -21,3 +19,6 @@ def register():
     Pool.register(
         purchase.HandlePurchaseCancellationException,
         module='sale_supply', type_='wizard')
+    Pool.register(
+        stock.OrderPoint,
+        module='sale_supply', type_='model', depends=['stock_supply'])
