@@ -4,8 +4,8 @@ from functools import wraps
 
 from trytond.model import ModelView, Workflow, fields
 from trytond.pool import Pool, PoolMeta
-from trytond.transaction import Transaction
 from trytond.tools import grouped_slice
+from trytond.transaction import Transaction, without_check_access
 
 
 class Request(metaclass=PoolMeta):
@@ -29,8 +29,10 @@ class Request(metaclass=PoolMeta):
         pool = Pool()
         Sale = pool.get('sale.sale')
         SaleLine = pool.get('sale.line')
+        transaction = Transaction()
+        context = transaction.context
 
-        with Transaction().set_context(_check_access=False):
+        with without_check_access():
             reqs = cls.browse(requests)
             sales = set(r.origin for r in reqs if isinstance(r.origin, Sale))
             sale_lines = [l for r in reqs for l in r.sale_lines]
@@ -42,7 +44,9 @@ class Request(metaclass=PoolMeta):
         super().delete(requests)
 
         if sales:
-            Sale.__queue__.process(sales)
+            with transaction.set_context(
+                    queue_batch=context.get('queue_batch', True)):
+                Sale.__queue__.process(sales)
 
 
 def process_sale_supply(func):
@@ -51,9 +55,11 @@ def process_sale_supply(func):
         pool = Pool()
         Request = pool.get('purchase.request')
         Sale = pool.get('sale.sale')
+        transaction = Transaction()
+        context = transaction.context
 
         sales = set()
-        with Transaction().set_context(_check_access=False):
+        with without_check_access():
             for sub_purchases in grouped_slice(purchases):
                 ids = [x.id for x in sub_purchases]
                 requests = Request.search([
@@ -63,7 +69,9 @@ def process_sale_supply(func):
                 sales.update(r.origin.id for r in requests)
         func(cls, purchases)
         if sales:
-            Sale.__queue__.process(sales)
+            with transaction.set_context(
+                    queue_batch=context.get('queue_batch', True)):
+                Sale.__queue__.process(sales)
     return wrapper
 
 
